multidim.covertree.CoverLevel
=============================

.. currentmodule:: multidim.covertree

.. autoclass:: CoverLevel

   

      .. autosummary::
         :toctree:
      
         CoverLevel.check
         CoverLevel.cleanup
         CoverLevel.find_entropy
         CoverLevel.find_label_weights
         CoverLevel.plot
         CoverLevel.plot_data_title



   

